mock-django
~~~~~~~~~~~

A simple library for mocking certain Django behavior, such as the ORM.

Testing
-------

.. image:: https://secure.travis-ci.org/dcramer/mock-django.png
   :alt: Build Status
   :target: http://travis-ci.org/dcramer/mock-django

``python setup.py test``
